@@ -1,12 +1,14 @@
 
-__version__ = '0.9.4'
+__version__ = '0.9.5'
 
 from ._orflist import *
 from ._references import *
+from ._scorematrix import *
 from ._util import *
 
 
 __all__ = []
 __all__ += _orflist.__all__
 __all__ += _references.__all__
+__all__ += _scorematrix.__all__
 __all__ += _util.__all__
